summaryrefslogtreecommitdiff
path: root/src/cos_parse.h
diff options
context:
space:
mode:
authorVincent Sanders <vince@kyllikki.org>2018-01-18 00:21:10 +0000
committerVincent Sanders <vince@kyllikki.org>2018-01-18 00:21:10 +0000
commitb1e0e4414ecd3161c0f947daceb8643b5889e51c (patch)
treeab63f66b3651856f3528bb51e9acf522d0854521 /src/cos_parse.h
parentc27eb52f96f8070c4be77a387e603508fc4092ce (diff)
downloadlibnspdf-b1e0e4414ecd3161c0f947daceb8643b5889e51c.tar.gz
libnspdf-b1e0e4414ecd3161c0f947daceb8643b5889e51c.tar.bz2
start to alter parseing to read from cos_stream object
Diffstat (limited to 'src/cos_parse.h')
-rw-r--r--src/cos_parse.h8
1 files changed, 7 insertions, 1 deletions
diff --git a/src/cos_parse.h b/src/cos_parse.h
index 0bca79f..8f48108 100644
--- a/src/cos_parse.h
+++ b/src/cos_parse.h
@@ -17,12 +17,18 @@
struct nspdf_doc;
struct cos_object;
+struct cos_stream;
/**
* Decode input stream into an object
*
* lex and parse a byte stream to generate a COS object.
*/
nspdferror cos_parse_object(struct nspdf_doc *doc, uint64_t *offset_out, struct cos_object **cosobj_out);
+/**
+ * Parse content stream into content operations object
+ */
+nspdferror cos_parse_content_stream(struct nspdf_doc *doc, struct cos_stream *stream, struct cos_object **content_out);
+
#endif
@@ -17,12 +17,18 @@
/**
- * Decode input stream into an object
+ * Parse input stream into an object
*
* lex and parse a byte stream to generate a COS object.